@@ -11,14 +11,15 @@ subdirectory that contains the files needed to run the application.
 
 from __future__ import annotations
 
-from cx_Freeze import Executable, setup
+from cx_Freeze import setup
 
 try:
     from cx_Freeze.hooks import get_qt_plugins_paths
 except ImportError:
     get_qt_plugins_paths = None
 
-include_files = []
+include_files = [("logo.svg", "share/logo.svg")]
+
 if get_qt_plugins_paths:
     # Inclusion of extra plugins (since cx_Freeze 6.8b2)
     # cx_Freeze automatically imports the following plugins depending on the
@@ -32,12 +33,10 @@ build_exe_options = {
     "include_files": include_files,
 }
 
-executables = [Executable("test_pyqt6.py", base="gui")]
-
 setup(
     name="simple_pyqt6",
     version="7.2",
     description="Sample cx_Freeze PyQt6 script",
+    executables=[{"script": "test_pyqt6.py", "base": "gui"}],
     options={"build_exe": build_exe_options},
-    executables=executables,
 )
